export default class DashboardConditionalLogicUI {

	LOGIC_GROUP_ACTION = 'wps_render_logic_group';
	SINGLE_LOGIC_ACTION = 'wps_render_single_logic';
	SINGLE_CLUSTER_ACTION = 'wps_render_single_cluster';
	CONDITION_FIELD_ACTION = 'wps_render_condition_field';
	SEARCH_PRODUCTS_ACTION = 'wps_ajax_search_products';
	SELECT2_FIELD_CLASS = '.wps-logic-condition__value-select2';
	SELECT2_PRODUCT_FIELD_CLASS = '.wps-logic-condition__value-select2_product-search';


	removeCondition( buttonElement ) {

		const $conditionsWrapper = jQuery( buttonElement ).closest( '.wps-logic-group__cluster' ).find( '.wps-logic-cluster__conditions-wrapper' );
		jQuery( buttonElement ).closest( '.wps-logic-group__condition' ).remove();

		if ( $conditionsWrapper.children().length === 0 ) {
			this.removeCluster( $conditionsWrapper );
		}
	}

	removeCluster( buttonElement ) {
		jQuery( buttonElement ).closest( '.wps-logic-group__cluster' ).remove();
	}

	removeGroup( buttonElement ) {
		jQuery( buttonElement ).closest( '.wps-logic-group' ).remove();
	}

	rednerNewGroup() {
		const data = {
			action: this.LOGIC_GROUP_ACTION,
			nonce: ajaxObj.nonce
		};

		jQuery.ajax(
			{
				type: 'POST',
				url: ajaxObj.ajaxUrl,
				data: data,
				success: ( data ) => {
					jQuery( '.wps-logic-groups__wrapper' ).append( data[ 'data' ] );
					this.initSelect2Fields();
				},
				error: function ( data ) {
					console.error( "Error while rendering new group", data );
				}
			}
		);

	}

	renderNewCondition( buttonElement ) {
		const data = {
			action: this.SINGLE_LOGIC_ACTION,
			groupId: jQuery( buttonElement ).closest( '.wps-logic-group' ).data( 'group-id' ),
			clusterId: jQuery( buttonElement ).closest( '.wps-logic-cluster' ).data( 'cluster-id' ),
			nonce: ajaxObj.nonce
		};

		jQuery.ajax(
			{
				type: 'POST',
				url: ajaxObj.ajaxUrl,
				data: data,
				success: ( data ) => {
					jQuery( buttonElement ).closest( '.wps-logic-group__cluster' ).find( '.wps-logic-cluster__conditions-wrapper' ).append( data[ 'data' ] );
					this.initSelect2Fields();
				},
				error: function ( data ) {
					console.error( "Error while rendering new condition cluster", data );
				}
			}
		);
	}

	renderNewCluster( buttonElement ) {
		const data = {
			action: this.SINGLE_CLUSTER_ACTION,
			groupId: jQuery( buttonElement ).closest( '.wps-logic-group' ).data( 'group-id' ),
			nonce: ajaxObj.nonce
		};

		jQuery.ajax(
			{
				type: 'POST',
				url: ajaxObj.ajaxUrl,
				data: data,
				success: ( data ) => {
					jQuery( buttonElement ).closest( '.wps-logic-group' ).find( '.wps-logic-group__clusters-wrapper' ).append( data[ 'data' ] );
					this.initSelect2Fields();
				},
				error: function ( data ) {
					console.log( data );
				}
			}
		);
	}

	renderConditionFields( element ) {
		const data = {
			action: this.CONDITION_FIELD_ACTION,
			selectedCondition: jQuery( element ).closest( '.wps-logic-condition__base' ).val(),
			groupId: jQuery( element ).closest( '.wps-logic-group' ).data( 'group-id' ),
			clusterId: jQuery( element ).closest( '.wps-logic-condition__base' ).data( 'cluster-id' ),
			conditionId: jQuery( element ).closest( '.wps-logic-condition__base' ).data( 'condition-id' ),
			nonce: ajaxObj.nonce
		};

		jQuery.ajax(
			{
				type: 'POST',
				url: ajaxObj.ajaxUrl,
				data: data,
				success: ( data ) => {
					const $valueWrapper = jQuery( element ).closest( '.wps-logic-group__condition' ).find( '.wps-logic-condition__value-wrapper' );
					const $statementWrapper = jQuery( element ).closest( '.wps-logic-group__condition' ).find( '.wps-logic-condition__statement-wrapper' );
					$valueWrapper.html( data[ 'data' ][ 'values' ] );
					$statementWrapper.html( data[ 'data' ][ 'statements' ] );
					this.initSelect2Fields();
				},
				error: function ( data ) {
					console.error( "Error while rendering condition fields", data );
				}
			}
		);
	}

	initSelect2Fields() {
		jQuery( this.SELECT2_FIELD_CLASS ).select2();
		jQuery( this.SELECT2_PRODUCT_FIELD_CLASS ).select2( {
				ajax: {
					url: ajaxObj.ajaxUrl,
					dataType: 'json',
					delay: 250,
					data: ( { term } ) => ( {
						q: term,
						action: this.SEARCH_PRODUCTS_ACTION,
					} ),
					processResults: ( data ) => ({
							results: jQuery.map( data, function ( item ) {
								return {
									id: item.id,
									text: item.text,
								};
							} ),
					}),
					cache: true,
				},
				minimumInputLength: 3,
			}
		);
	}
}
