<?php

namespace WPDesk\WooCommercePaymentStatus\Conditional\Conditions;

abstract class AbstractCondition implements Condition {

	protected array $value;
	protected string $operator;
	protected string $uniqid;
	protected string $cluster_id;
	protected string $group_id;

	abstract public function get_id(): string;

	public function __construct( string $condition_id, string $cluster_id, string $group_id ) {
		$this->uniqid     = $condition_id;
		$this->cluster_id = $cluster_id;
		$this->group_id   = $group_id;
	}

	public function get_condition_id(): string {
		return $this->uniqid ?? \uniqid();
	}

	public function get_cluster_id(): string {
		return $this->cluster_id;
	}

	public function get_group_id(): string {
		return $this->group_id;
	}

	public function get_condition(): string {
		return $this->get_id() ?? '';
	}

	public function set_value( array $value ): Condition {
		$this->value = $value;

		return $this;
	}

	public function get_value(): array {
		return empty( $this->value ) ? $this->get_default_value() : $this->value;
	}

	public function set_statement( $operator ): Condition {
		$this->operator = $operator;

		return $this;
	}

	public function get_statement(): string {
		return $this->operator ?? '';
	}

	public function get_statements(): array {
		return array(
			'is'     => __( 'Is', 'wpdesk-wps' ),
			'is_not' => __( 'Is not', 'wpdesk-wps' ),
		);
	}

	public function get_default_value(): array {
		return array( array_key_first( $this->get_available_options() ) );
	}
}
