<?php

namespace WPDesk\WooCommercePaymentStatus\Conditional\Conditions;

class GatewayCondition extends AbstractCondition {


	private const IS_STATEMENT     = 'is';
	private const IS_NOT_STATEMENT = 'is_not';

	public function get_id(): string {
		return 'gateway';
	}

	public function get_name(): string {
		return __( 'Payment gateway', 'wpdesk-wps' );
	}

	public function is_satisfied( \WC_Order $order ): bool {

		$payment_method = $order->get_payment_method();
		$statement      = $this->get_statement();

		if ( empty( $payment_method ) ) {
			return false;
		}
		if ( $statement === self::IS_STATEMENT ) {
			return in_array( $payment_method, $this->value, true );
		}

		if ( $statement === self::IS_NOT_STATEMENT ) {
			return ! in_array( $payment_method, $this->value, true );
		}

		return false;
	}

	public function get_available_options(): array {

		$available_gateways = WC()->payment_gateways()->payment_gateways();
		$enabled_gateways   = array();
		foreach ( $available_gateways as $gateway ) {
			$enabled_gateways[ $gateway->id ] = $gateway->title;
		}

		return $enabled_gateways;
	}
}
