<?php

namespace WPDesk\WooCommercePaymentStatus\Conditional\Conditions;

class ProductCategoryCondition extends AbstractCondition {


	private const IS_STATEMENT     = 'is';
	private const IS_NOT_STATEMENT = 'is_not';

	public function get_id(): string {
		return 'product_category';
	}

	public function get_name(): string {
		return __( 'Product category', 'wpdesk-wps' );
	}

	public function get_available_options(): array {
		$categories = get_categories(
			array(
				'taxonomy'     => 'product_cat',
				'orderby'      => 'name',
				'pad_counts'   => false,
				'hierarchical' => 1,
				'hide_empty'   => false,
			)
		);

		$categories = wp_list_pluck( $categories, 'name', 'term_id' );

		return $categories;
	}

	public function is_satisfied( \WC_Order $order ): bool {

		$statement = $this->get_statement();

		$items = $order->get_items();

		foreach ( $items as $item ) {
			$product    = $item->get_product();
			$categories = array_values( $product->get_category_ids() );

			foreach ( $this->value as $value ) {
				if ( ( $statement === self::IS_STATEMENT ) ) {
					return in_array( (int) $value, $categories, true );
				}

				if ( $statement === self::IS_NOT_STATEMENT ) {
					return ! in_array( (int) $value, $categories, true );
				}
			}
		}

		return false;
	}
}
