<?php

namespace WPDesk\WooCommercePaymentStatus\Conditional\Conditions;

class ProductCondition extends AbstractCondition {

	private const IS_STATEMENT     = 'is';
	private const IS_NOT_STATEMENT = 'is_not';

	public function get_id(): string {
		return 'product';
	}

	public function get_name(): string {
		return __( 'Product', 'wpdesk-wps' );
	}

	public function get_available_options(): array {
		$values = $this->value ?? [];

		$products       = wc_get_products(
			[
				'include' => $values,
			]
		);
		$products_array = [];

		foreach ( $products as $product ) {
			$products_array[ $product->get_id() ] = $product->get_name();
		}

		return $products_array;
	}

	public function is_satisfied( \WC_Order $order ): bool {
		$items = $order->get_items();

		$product_ids = $this->get_product_ids_from_order_items( $items );

		if ( count( $product_ids ) > 0 ) {
			$statement = $this->get_statement();


			foreach ( $this->value as $product ) {
				if ( in_array( (int) $product, $product_ids, true ) ) {


					if ( $statement === self::IS_STATEMENT ) {
						return true;
					}
					if ( $statement === self::IS_NOT_STATEMENT ) {
						return false;
					}

				}
			}

			if ( $statement === self::IS_STATEMENT ) {
				return false;
			}
			if ( $statement === self::IS_NOT_STATEMENT ) {
				return true;
			}

		}

		return false;
	}

	/**
	 * @param array $items [string|int => WC_Order_Item]
	 *
	 * @return array
	 */
	private function get_product_ids_from_order_items( array $items ): array {

		$product_ids = [];
		foreach ( $items as $item ) {
			$product_ids[] = $item->get_product_id();
		}
		return $product_ids;
	}
}
