<?php

namespace WPDesk\WooCommercePaymentStatus\Conditional\Conditions;

class ProductTypeCondition extends AbstractCondition {

	public const CONDITION_AT_LEAST_ONE    = 'at_least_one';
	public const CONDITION_ALL             = 'all';
	public const STATEMENT_IS_VITUAL       = 'is_virtual';
	private const STATEMENT_IS_NOT_VIRTUAL  = 'is_not_virtual';

	public function get_id(): string {
		return 'product_type';
	}

	public function get_name(): string {
		return __( 'Product type', 'wpdesk-wps' );
	}

	public function get_available_options(): array {

		return array(
			self::CONDITION_AT_LEAST_ONE => esc_html__( 'In at least one item in the order', 'wpdesk-wps' ),
			self::CONDITION_ALL          => esc_html__( 'In all items in the order', 'wpdesk-wps' ),
		);
	}

	public function is_satisfied( \WC_Order $order ): bool {

		$condition = $this->get_value()[0];

		$items = $order->get_items();

		if ( $condition === self::CONDITION_ALL ) {
			return $this->is_satisfied_for_all( $items );
		}

		if ( $condition === self::CONDITION_AT_LEAST_ONE ) {
			return $this->is_satisfied_for_at_least_one( $items );
		}

		return false;
	}

	private function is_satisfied_for_all( array $items ): bool {
		$statement = $this->get_statement();

		foreach ( $items as $item ) {
			$product = $item->get_product();

			if ( $product->is_type( 'variable' ) ) {
				$variation = wc_get_product( $item['variation_id'] );
				if ( ( $statement === self::STATEMENT_IS_NOT_VIRTUAL ) && $variation->is_virtual() ) {
					return false;
				}
				if ( ( $statement === self::STATEMENT_IS_VITUAL ) && ! $variation->is_virtual() ) {
					return false;
				}
			} else {
				if ( ( $statement === self::STATEMENT_IS_NOT_VIRTUAL ) && $product->is_virtual() ) {
					return false;
				}
				if ( ( $statement === self::STATEMENT_IS_VITUAL ) && ! $product->is_virtual() ) {
					return false;
				}
			}
		}

		return true;
	}

	private function is_satisfied_for_at_least_one( array $items ): bool {
		$statement = $this->get_statement();

		foreach ( $items as $item ) {
			$product = $item->get_product();

			if ( $product->is_type( 'variable' ) ) {
				$variation = wc_get_product( $item['variation_id'] );
				if ( $statement === self::STATEMENT_IS_NOT_VIRTUAL && ! $variation->is_virtual() ) {
					return true;
				}
				if ( $statement === self::STATEMENT_IS_VITUAL && $variation->is_virtual() ) {
					return true;
				}
			} else {
				if ( $statement === self::STATEMENT_IS_NOT_VIRTUAL && ! $product->is_virtual() ) {
					return true;
				}
				if ( ( $statement === self::STATEMENT_IS_VITUAL ) && $product->is_virtual() ) {
					return true;
				}
			}
		}

		return false;
	}


	public function get_statements(): array {
		return array(
			self::STATEMENT_IS_VITUAL      => __( 'Is virtual', 'wpdesk-wps' ),
			self::STATEMENT_IS_NOT_VIRTUAL => __( 'Is not virtual', 'wpdesk-wps' ),
		);
	}
}
