<?php

namespace WPDesk\WooCommercePaymentStatus\Conditional;

use WPDesk\WooCommercePaymentStatus\Conditional\Clusters\ConditionsCluster;
use WPDesk\WooCommercePaymentStatus\Conditional\Conditions\Condition;
use WPDesk\WooCommercePaymentStatus\Conditional\Conditions\GatewayCondition;
use WPDesk\WooCommercePaymentStatus\Conditional\Conditions\ProductCategoryCondition;
use WPDesk\WooCommercePaymentStatus\Conditional\Conditions\ProductCondition;
use WPDesk\WooCommercePaymentStatus\Conditional\Conditions\ProductTypeCondition;
use WPDesk\WooCommercePaymentStatus\Conditional\Groups\Group;

class ConditionsCreator {

	public function create_condition( string $group_id, string $cluster_id, string $condition_id, string $type = Conditions::GATEWAY_KEY ): Condition {
		switch ( $type ) {
			case Conditions::PRODUCT_TYPE_KEY:
				return new ProductTypeCondition( $condition_id, $cluster_id, $group_id );
			case Conditions::PRODUCT_CATEGORY_KEY:
				return new ProductCategoryCondition( $condition_id, $cluster_id, $group_id );
			case Conditions::PRODUCT_KEY:
				return new ProductCondition( $condition_id, $cluster_id, $group_id );
			default:
				return new GatewayCondition( $condition_id, $cluster_id, $group_id );
		}
	}

	public function create_empty_condition( string $group_id, string $cluster_id ): Condition {
		return new GatewayCondition( uniqid(), $cluster_id, $group_id );
	}

	public function create_empty_cluster( string $group_id ): ConditionsCluster {
		$blank_cluster = new ConditionsCluster( uniqid(), $group_id );

		$blank_condition = $this->create_empty_condition( $group_id, $blank_cluster->get_cluster_id() );
		$blank_cluster->add_condition( $blank_condition );

		return $blank_cluster;
	}

	public function create_empty_group(): Group {
		$blank_group = new Group( uniqid() );

		$blank_cluster = $this->create_empty_cluster( $blank_group->get_group_id() );

		$blank_group->add_cluster( $blank_cluster );

		return $blank_group;
	}
}
