<?php

namespace WPDesk\WooCommercePaymentStatus;

use WPDesk\WooCommercePaymentStatus\Settings\Settings;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\Hookable;

/**
 * WooCommerce Integration.
 */
class Integration implements Hookable {

	public const  PAGE_SLUG           = 'wpdesk-wps';
	private const WC_STATUS_COMPLETED = 'wc-completed';

	private Settings $settings;


	public function __construct( Settings $settings ) {
		$this->settings = $settings;
	}

	public function hooks() {
		add_action( 'woocommerce_order_status_processing', [ $this, 'maybe_update_order_status' ] );
	}

	public function maybe_update_order_status( $order_id ) {

		$general_option = $this->settings->get_general_condition();

		if ( $general_option === Settings::GENERAL_CONDITION_NEVER ) {
			return;
		}

		if ( $general_option === Settings::GENERAL_CONDITION_CONDITIONAL ) {
			$order = wc_get_order( $order_id );

			$conditional_logic = $this->settings->get_conditional_logic();

			$order_status = false;

			foreach ( $conditional_logic->get_groups() as $group ) {
				if ( $group->is_group_satisfied( $order ) ) {
					$order_status = $group->get_target_status();
				}
			}

			if ( $order_status ) {
				$this->update_order_status( $order, $order_status );
			}
		} else if ( $general_option === Settings::GENERAL_CONDITION_ALWAYS ) {
			$order = wc_get_order( $order_id );
			$this->update_order_status( $order );
		}
	}

	private function update_order_status( $order, $order_status = self::WC_STATUS_COMPLETED ): void {
		$note = apply_filters( 'woocommerce_payment_status_note', __( 'Order status automatically changed by WooCommerce Automatic Payment Status plugin.', 'wpdesk-wps' ) );
		$order->update_status( $order_status, $note );
		$order->save();
	}
}
