<?php
/**
 * Plugin main class.
 *
 * @package WPDesk\WooCommerce_Payment_Status_Plugin
 */

namespace WPDesk\WooCommercePaymentStatus;

use WPDesk\WooCommercePaymentStatus\Conditional\Conditions;
use WPDesk\WooCommercePaymentStatus\Conditional\ConditionsCreator;
use WPDesk\WooCommercePaymentStatus\Settings\Settings;
use WPDesk\WooCommercePaymentStatus\Settings\SettingsPage;
use WPDesk\WooCommercePaymentStatus\Settings\SettingsPageRenderer;
use WPDesk\WooCommercePaymentStatus\Settings\Tabs\General;
use WPDesk\WooCommercePaymentStatus\UI\AjaxRenderer;
use WPDesk\WooCommercePaymentStatus\UI\UIRenderer;
use WPStatusVendor\WPDesk\Dashboard\DashboardWidget;
use WPStatusVendor\WPDesk\Forms\Resolver\DefaultFormFieldResolver;
use WPStatusVendor\WPDesk\Persistence\Adapter\WordPress\WordpressOptionsContainer;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\AbstractPlugin;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\HookableCollection;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\HookableParent;
use WPStatusVendor\WPDesk\View\Renderer\Renderer;
use WPStatusVendor\WPDesk\View\Renderer\SimplePhpRenderer;
use WPStatusVendor\WPDesk\View\Resolver\ChainResolver;
use WPStatusVendor\WPDesk\View\Resolver\DirResolver;
use WPStatusVendor\WPDesk_Plugin_Info;

class Plugin extends AbstractPlugin implements HookableCollection {

	use HookableParent;

	/**
	 * @param WPDesk_Plugin_Info $plugin_info Plugin info.
	 */
	public function __construct( WPDesk_Plugin_Info $plugin_info ) {
		$this->plugin_info = $plugin_info;
		parent::__construct( $this->plugin_info );

		$this->docs_url     = get_locale() === 'pl_PL' ? 'https://www.wpdesk.pl/docs/statusy-zamowien-woocommerce-docs/' : 'https://www.wpdesk.net/docs/automatic-payment-status-woocommerce/';
		$this->docs_url    .= '?utm_source=wp-admin-plugins&utm_medium=quick-link&utm_campaign=woocommerce-payment-status-docs-link';
		$this->support_url  = get_locale() === 'pl_PL' ? 'https://www.wpdesk.pl/support/' : 'https://www.wpdesk.net/support/';
		$this->settings_url = admin_url( 'admin.php?page=' . Integration::PAGE_SLUG );
	}

	/**
	 * Fires hooks
	 */
	public function hooks() {
		parent::hooks();
		( new DashboardWidget() )->hooks();

		add_action('init', function (){
			$available_conditions = new Conditions();
			$conditions_creator   = new ConditionsCreator();
			$settings             = new Settings( new WordpressOptionsContainer( Settings::SETTINGS_PREFIX ), $conditions_creator );

			$this->add_hookable( new Integration( $settings ) );
			$this->add_hookable( new AjaxRenderer( $this->get_renderer(), $available_conditions, $conditions_creator ) );

			/* Settings page */
			$form_renderer = $this->get_form_renderer();
			$ui_renderer   = new UIRenderer( $this->get_renderer(), $available_conditions, $conditions_creator );
			$page_renderer = new SettingsPageRenderer( $form_renderer );
			$general_tab   = new General( $settings, $form_renderer, $this->docs_url, $this->plugin_info, $ui_renderer );
			$this->add_hookable( new SettingsPage( $page_renderer, $general_tab ) );

			$this->hooks_on_hookable_objects();
		});

	}

	private function get_form_renderer(): Renderer {
		$resolver = new ChainResolver();

		$resolver->appendResolver( new DirResolver( $this->plugin_info->get_plugin_dir() . '/src/Views' ) );
		$resolver->appendResolver( new DefaultFormFieldResolver() );

		return new SimplePhpRenderer( $resolver );
	}

	private function get_renderer(): Renderer {
		$resolver = new ChainResolver();

		$resolver->appendResolver( new DirResolver( $this->plugin_info->get_plugin_dir() . '/src/Views' ) );

		return new SimplePhpRenderer( $resolver );
	}
}
