<?php

namespace WPDesk\WooCommercePaymentStatus\Settings\Compatibility;

use WPDesk\WooCommercePaymentStatus\Conditional\Clusters\ConditionsCluster;
use WPDesk\WooCommercePaymentStatus\Conditional\Conditions;
use WPDesk\WooCommercePaymentStatus\Conditional\ConditionsCreator;
use WPDesk\WooCommercePaymentStatus\Conditional\Groups\Group;
use WPDesk\WooCommercePaymentStatus\Settings\Settings;


/**
 * Backwards compatibility for versions below 2.0.0
 */
class BackwardCompatibility {

	private const BACKWARD_COMPATIBILITY_OPTION_KEY = 'woocommerce_paymentstatus_mode';
	private const WC_ORDER_STATUS_COMPLETED         = 'wc-completed';

	private const NEVER_COMPLETE_ORDERS_KEY = 0;
	private const AT_LEAST_ONE_VIRTUAL_KEY  = 1;
	private const ONLY_VIRTUAL_KEY          = 2;
	public const ALL_ORDERS_KEY            = 3;
	private ConditionsCreator $conditions_creator;

	public function __construct( ConditionsCreator $conditions_creator ) {
		$this->conditions_creator = $conditions_creator;
	}

	public function get_previous_settings_with_new_format():string{
		$selected_mode = $this->get_previous_option();

		switch ( $selected_mode ) {
			case self::AT_LEAST_ONE_VIRTUAL_KEY:
			case self::ONLY_VIRTUAL_KEY:
				return Settings::GENERAL_CONDITION_CONDITIONAL;
			case self::ALL_ORDERS_KEY:
				return Settings::GENERAL_CONDITION_ALWAYS;
			default:
				return Settings::GENERAL_CONDITION_NEVER;
		}
	}

	public function is_previous_settings_with_conditions(): bool {
		$selected_mode = $this->get_previous_option();

		return in_array( $selected_mode, [
			self::AT_LEAST_ONE_VIRTUAL_KEY,
			self::ONLY_VIRTUAL_KEY,
		], true );
	}

	/**
	 * Available options:
	 * 0 = Do not autocomplete orders
	 * 1 = Orders with at least one virtual product
	 * 2 = Order with only virtual products
	 * 3 = All orders
	 */
	public function get_previous_option(): int {
		return (int) get_option( self::BACKWARD_COMPATIBILITY_OPTION_KEY );
	}

	public function create_group(): Group {
		$selected_mode = $this->get_previous_option();

		switch ( $selected_mode ) {
			case self::AT_LEAST_ONE_VIRTUAL_KEY:
				$backward_value = Conditions\ProductTypeCondition::CONDITION_AT_LEAST_ONE;
				break;
			case self::ONLY_VIRTUAL_KEY:
				$backward_value = Conditions\ProductTypeCondition::CONDITION_ALL;
				break;
			default:
				return new Group( uniqid() );
		}

		$group = new Group( uniqid() );
		$group->set_target_status( self::WC_ORDER_STATUS_COMPLETED );
		$cluster   = new ConditionsCluster( uniqid(), $group->get_group_id() );
		$condition = $this->conditions_creator->create_condition( $group->get_group_id(), $cluster->get_cluster_id(), uniqid(), Conditions::PRODUCT_TYPE_KEY );

		$condition
			->set_value( [ $backward_value ] )
			->set_statement( Conditions\ProductTypeCondition::STATEMENT_IS_VITUAL );

		$cluster->add_condition( $condition );
		$group->add_cluster( $cluster );

		return $group;

	}
}
