<?php

namespace WPDesk\WooCommercePaymentStatus\Settings\Fields;

use WPDesk\WooCommercePaymentStatus\Settings\Settings;
use WPDesk\WooCommercePaymentStatus\UI\Elements\GroupUIElement;
use WPDesk\WooCommercePaymentStatus\UI\UIRenderer;
use WPStatusVendor\WPDesk\Forms\Field\BasicField;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WPStatusVendor\WPDesk_Plugin_Info;

class LogicGroups extends BasicField implements Hookable {


	public const AJAX_NONCE = 'wps_logicgroups-ajax-nonce';
	private UIRenderer $ui_renderer;
	private Settings $settings;
	private WPDesk_Plugin_Info $plugin_info;

	public function __construct( UIRenderer $ui_renderer, Settings $settings, WPDesk_Plugin_Info $plugin_info ) {
		$this->ui_renderer = $ui_renderer;
		$this->settings    = $settings;
		$this->plugin_info = $plugin_info;
	}

	public function should_override_form_template(): bool {
		return true;
	}

	public function get_template_name(): string {
		return 'fields/logic-groups';
	}

	public function get_general_condition():string{
		return $this->settings->get_general_condition();
	}

	public function get_rendered_logic_groups(): string {

		$conditional_logic = $this->settings->get_conditional_logic();

		$rendered_logic_groups = '';

		foreach ( $conditional_logic->get_groups() as $group ) {

			$group_ui_element = new GroupUIElement( $group );

			$rendered_logic_groups .= $this->ui_renderer->render_group( $group_ui_element );
		}

		return $rendered_logic_groups;
	}

	/**
	 * @return void
	 *
	 * Enqueue js scripts and css styles required for proper functionality of this field.
	 */
	public function hooks() {
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_filter(
			'script_loader_tag',
			function ( $tag, $handle ) {
				if ( 'wps-logic-group-script' === $handle ) {
					$tag = str_replace( '<script ', '<script type="module" ', $tag );
				}
				return $tag;
			},
			10,
			2
		);
	}

	public function admin_enqueue_scripts() {
		wp_enqueue_script( 'selectWoo' );
		wp_enqueue_style( 'selectWoo', WC()->plugin_url() . '/assets/css/select2.css' );

		$and_statement = __( 'AND', 'wpdesk-wps' );
		$or_statement  = __( 'OR', 'wpdesk-wps' );

		wp_enqueue_style( 'wps-logic-group-style', $this->plugin_info->get_plugin_url() . '/assets/css/fields/logic-groups.css', array(), $this->plugin_info->get_version() );
		wp_add_inline_style(
			'wps-logic-group-style',
			'
		.wps-logic-group__condition:not(.wps-logic-group__condition:first-child):before {content: "' . $and_statement . '";}
		.wps-logic-group__cluster:not(.wps-logic-group__cluster:first-child):before {content: "' . $or_statement . '";}'
		);

		wp_enqueue_script( 'wps-logic-group-script', $this->plugin_info->get_plugin_url() . '/assets/js/main.js', array( 'jquery' ), $this->plugin_info->get_version() );
		wp_localize_script(
			'wps-logic-group-script',
			'ajaxObj',
			array(
				'ajaxUrl' => admin_url( 'admin-ajax.php' ),
				'nonce'   => wp_create_nonce( self::AJAX_NONCE ),
			)
		);
	}
}
