<?php

namespace WPDesk\WooCommercePaymentStatus\Settings;

use WPDesk\WooCommercePaymentStatus\Settings\Tabs\General;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\Hookable;

class SettingsPage implements Hookable {

	private const PAGE_ID = 'wpdesk-wps';
	private General $general_tab;
	private SettingsPageRenderer $page_renderer;


	public function __construct( SettingsPageRenderer $page_renderer, General $general_tab ) {
		$this->page_renderer = $page_renderer;
		$this->general_tab   = $general_tab;
	}

	public function hooks() {
		add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
		add_action( 'admin_post_wpdesk_wps_save_settings', array( $this, 'save_tab_settings' ) );
	}

	public function add_admin_menu(): void {
		add_submenu_page(
			'woocommerce',
			__( 'Autocomplete Orders', 'wpdesk-wps' ),
			__( 'Autocomplete Orders', 'wpdesk-wps' ),
			'manage_woocommerce',
			self::PAGE_ID,
			array( $this, 'render' )
		);
	}

	public function render(): void {
		$this->page_renderer->render( $this->general_tab );
	}

	public function save_tab_settings(): void {
		if ( ! current_user_can( 'manage_woocommerce' ) ) {
			wp_die( esc_html__( 'Permission denied', 'wpdesk-wps' ) );
		}

		$this->general_tab->save_settings();
	}
}
