<?php

namespace WPDesk\WooCommercePaymentStatus\Settings\Tabs;

use WPDesk\WooCommercePaymentStatus\Settings\Fields\HiddenNonce;
use WPDesk\WooCommercePaymentStatus\Settings\Fields\LogicGroups;
use WPDesk\WooCommercePaymentStatus\Settings\Fields\WPAction;
use WPDesk\WooCommercePaymentStatus\Settings\Settings;
use WPDesk\WooCommercePaymentStatus\UI\UIRenderer;
use WPStatusVendor\WPDesk\Forms\Field\SubmitField;
use WPStatusVendor\WPDesk\Forms\Form\FormWithFields;
use WPStatusVendor\WPDesk\View\Renderer\Renderer;
use WPStatusVendor\WPDesk_Plugin_Info;

class General implements Tab {

	private const NONCE_ACTION = 'save-wpstatus-settings';
	private const NONCE_NAME   = '_wpnonce';
	private const FORM_ID      = 'wps-settings';


	private string $docs_url;
	private FormWithFields $form_with_fields;
	private Settings $settings;

	private Renderer $renderer;

	private WPDesk_Plugin_Info $plugin_info;
	private UIRenderer $ui_renderer;


	public function __construct( Settings $settings, Renderer $renderer, string $docs_url, WPDesk_Plugin_Info $plugin_info, UIRenderer $ui_renderer ) {
		$this->settings         = $settings;
		$this->renderer         = $renderer;
		$this->plugin_info      = $plugin_info;
		$this->docs_url         = $docs_url;
		$this->ui_renderer      = $ui_renderer;
		$this->form_with_fields = new FormWithFields( $this->get_fields(), self::FORM_ID );
		$this->form_with_fields->set_action( admin_url( 'admin-post.php' ) );
	}


	public function get_fields(): array {

		$logic_groups = ( new LogicGroups( $this->ui_renderer, $this->settings, $this->plugin_info ) )
			->set_description(
				sprintf(
					__( 'Set when the order status in WooCommerce should change and what the target status should be. <br/> <b>Read more in the %1$splugin documentation ->%2$s</b>', 'wpdesk-wps' ),
					'<a class="wps-docs-url" href="' . esc_url( $this->docs_url ) . '" target="_blank">',
					'</a>'
				)
			)
			->set_label( __('Logic Groups', 'wpdesk-wps') );

		$logic_groups->hooks();

		return [
			( new HiddenNonce( self::NONCE_ACTION ) )
				->set_name( self::NONCE_NAME ),
			( new WPAction() )
				->set_action_name( 'wpdesk_wps_save_settings' ),
			$logic_groups,
			( new SubmitField() )
				->set_label( esc_html__( 'Save', 'wpdesk-wps' ) )
				->add_class( 'button-primary' )
				->set_name( 'wps-save' ),

		];
	}

	public function render_content(): string {
		$this->form_with_fields->set_data( $this->settings->get_settings() );

		return $this->form_with_fields->render_form( $this->renderer );
	}

	public function save_settings() {

		if ( isset( $_POST[ self::FORM_ID ] ) ) {
			if ( ! isset( $_POST[ self::FORM_ID ][ self::NONCE_NAME ] ) || ! wp_verify_nonce( sanitize_key( wp_unslash( $_POST[ self::FORM_ID ][ self::NONCE_NAME ] ) ), self::NONCE_ACTION ) ) {
				wp_die( esc_html__( 'This form has expired. Refresh the page.', 'wpdesk-wps' ) );
			}
			$this->settings->set( Settings::GENERAL_CONDITION_KEY, sanitize_key($_POST['wps-conditional-general-condition']) ?: Settings::GENERAL_CONDITION_NEVER );
			$this->settings->save_conditonal_logic( $_POST['wps-conditional'] ?? [] );
		}
		wp_safe_redirect( wp_get_referer() );
	}
}
