<?php

namespace WPDesk\WooCommercePaymentStatus\UI;

use WPDesk\WooCommercePaymentStatus\Settings\Fields\LogicGroups;
use WPStatusVendor\WPDesk\PluginBuilder\Plugin\Hookable;

class AjaxRenderer extends UIRenderer implements Hookable {

	private const SEARCH_PRODUCTS_LIMIT = 10;

	public function hooks() {
		add_action( 'wp_ajax_wps_render_logic_group', array( $this, 'wps_render_logic_group' ) );
		add_action( 'wp_ajax_wps_render_single_logic', array( $this, 'wps_render_single_logic' ) );
		add_action( 'wp_ajax_wps_render_single_cluster', array( $this, 'wps_render_single_cluster' ) );
		add_action( 'wp_ajax_wps_render_condition_field', array( $this, 'wps_render_condition_field' ) );
		add_action( 'wp_ajax_wps_ajax_search_products', array( $this, 'wps_ajax_search_products' ) );
	}

	public function wps_ajax_search_products(){
		$this->verfiy_permissions();

		$search_term = sanitize_text_field( $_GET['q'] );

		$products = wc_get_products([
			's' => $search_term,
			'limit' => self::SEARCH_PRODUCTS_LIMIT
		]);

		$results = [];
		foreach ( $products as $product ) {
			$results[] = [
				'id' => $product->get_id(),
				'text' => $product->get_name(),
			];
		}

		wp_send_json( $results );
	}

	private function verfiy_permissions(): void {
		if ( ! current_user_can( 'manage_woocommerce' ) ) {
			wp_send_json_error( __( 'Permission denied', 'wpdesk-wps' ) );
		}
	}

	private function verify_nonce(): void {
		$nonce = sanitize_text_field( $_POST['nonce'] );

		if ( ! wp_verify_nonce( $nonce, LogicGroups::AJAX_NONCE ) ) {
			wp_send_json_error( __( 'Invalid nonce', 'wpdesk-wps' ) );
		}
	}

	public function wps_render_logic_group(): void {
		$this->verify_nonce();
		$this->verfiy_permissions();

		$template = $this->render_empty_group();

		wp_send_json_success( $template );
	}

	public function wps_render_single_cluster(): void {
		$this->verify_nonce();
		$this->verfiy_permissions();

		$group_id = sanitize_text_field( $_POST['groupId'] );

		$template = $this->render_empty_cluster( $group_id );

		wp_send_json_success( $template );
	}

	public function wps_render_single_logic(): void {
		$this->verify_nonce();
		$this->verfiy_permissions();

		$group_id   = sanitize_text_field( $_POST['groupId'] );
		$cluster_id = sanitize_text_field( $_POST['clusterId'] );
		$template   = $this->render_empty_condition( $cluster_id, $group_id );

		wp_send_json_success( $template );
	}

	public function wps_render_condition_field(): void {
		$this->verify_nonce();
		$this->verfiy_permissions();

		$selected_condition = sanitize_text_field( $_POST['selectedCondition'] );
		$group_id           = sanitize_text_field( $_POST['groupId'] );
		$cluster_id         = sanitize_text_field( $_POST['clusterId'] );
		$condition_id       = sanitize_text_field( $_POST['conditionId'] );

		$condition            = $this->conditions_creator->create_condition( $group_id, $cluster_id, $condition_id, $selected_condition );
		$condition_input_name = $this->create_condition_input_name( $group_id, $cluster_id, $condition_id );

		$template['statements'] = $this->render_available_statements( $condition->get_statements(), $condition->get_statement(), $condition_input_name );
		$template['values']     = $this->render_available_values( $condition->get_available_options(), $condition->get_id(), $condition->get_value(), $condition_input_name );

		wp_send_json_success( $template );
	}
}
